@@ -1,8 +1,6 @@
 import logging, json, datetime
 from logging.handlers import DatagramHandler
 
-host = '54.254.228.180'
-port = 2435
 
 class ChaikaHandler(DatagramHandler):
 
